import {Component, inject, OnInit} from '@angular/core';
import {FormArray, FormBuilder, FormGroup, ReactiveFormsModule, Validators} from "@angular/forms";
import {MatFormField, MatLabel} from "@angular/material/form-field";
import {MatInput} from "@angular/material/input";
import {MatButton} from "@angular/material/button";
import {
  MatDialogActions,
  MatDialogClose,
  MatDialogContent,
  MatDialogRef,
  MatDialogTitle
} from "@angular/material/dialog";
import {Employee} from "../Employee";
import EmployeeApiService from "../../services/employee-api.service";
import {Observable} from "rxjs";
import {MatOption, MatSelect} from "@angular/material/select";
import {AsyncPipe, NgForOf, NgIf} from "@angular/common";
import {Qualification} from "../../Qualification";
import QualificationService from "../../services/qualification.service";

@Component({
  selector: 'app-create-employee',
  imports: [
    ReactiveFormsModule,
    MatFormField,
    MatInput,
    MatButton,
    MatLabel,
    MatDialogContent,
    MatDialogTitle,
    MatDialogActions,
    MatDialogClose,
    MatSelect,
    MatOption,
    NgForOf,
    NgIf,
    AsyncPipe,
  ],
  templateUrl: './create.component.html',
  standalone: true,
  styleUrl: './create.component.css'
})
export class CreateComponent implements OnInit {
  employeeForm: FormGroup | null = null;
  employeeService: EmployeeApiService = inject(EmployeeApiService);
  formBuilder: FormBuilder = inject(FormBuilder);
  dialogRef: MatDialogRef<CreateComponent> = inject(MatDialogRef);
  qualificationService: QualificationService = inject(QualificationService);
  skills!: Observable<Qualification[]>
  formSkills: FormArray = this.formBuilder.array([]);

  ngOnInit(): void {
    this.employeeForm = this.formBuilder.group({
      firstName: ['', Validators.required],
      lastName: ['', Validators.required],
      street: ['', Validators.required],
      postcode: ['', [Validators.required, Validators.minLength(5), Validators.maxLength(5)]],
      city: ['', Validators.required],
      phone: ['', Validators.required],
      skillSet: this.formSkills
    });

    this.skills = this.qualificationService.getAll();

    this.skills.subscribe((qualifications: Qualification[]) => {
      qualifications.forEach((qualification: Qualification) => {

        this.formSkills.push(this.formBuilder.group(qualification));
      });
    })
  }

  submit() {
    console.log(this.employeeForm?.controls['skillSet'].value)
    if (this.employeeForm === null || !this.employeeForm.valid) {
      console.error('Form invalid');
      return;
    }
    const newEmployee = this.employeeForm.value as Employee;
    //newEmployee.skillSet = newEmployee.skillSet?.map((selected: boolean, index: number) => {return })

    return;

    this.employeeService.create(newEmployee).subscribe();
    this.dialogRef.close();
  }
}
